pub enum BitConstraint {
Unrestrained,
Defined(bool),
Restrained,
}Expand description
Represent how a bit is limited in a pattern
Variants
Implementations
Sourceimpl BitConstraint
impl BitConstraint
Sourceimpl BitConstraint
impl BitConstraint
pub fn define(self, bit: bool) -> Option<Self>
Sourcepub fn most_restrictive(self, other: Self) -> Option<Self>
pub fn most_restrictive(self, other: Self) -> Option<Self>
select the most restrictive from both, None if they conflict
Sourcepub fn least_restrictive(self, other: Self) -> Self
pub fn least_restrictive(self, other: Self) -> Self
select the least restrictive from both