PatternLen

Enum PatternLen 

pub enum PatternLen {
    Defined(NumberUnsigned),
    Range {
        min: NumberUnsigned,
        max: NumberUnsigned,
    },
    Min(NumberUnsigned),
}

Variants

Implementations

Source

impl PatternLen

pub fn new(min: NumberUnsigned, max: NumberUnsigned) -> Self

new range/defined len for a pattern

pub fn is_recursive(&self) -> bool

is this pattern can contain itself and grown to infinite

pub fn min(&self) -> NumberUnsigned

min size of the token this patterns requires to match

pub fn max(&self) -> Option<NumberUnsigned>

max size of the token this patterns requires to match

pub fn single_len(&self) -> Option<NumberUnsigned>

token size, if this pattern is non-growing

pub fn concat(self, other: Self) -> Self

create a new range calculated from the concatenation of the two original ranges